==> mythplugins_0.18.1.orig.tar.gz: mythplugins-0.18.1/mythdvd/i18n/mythdvd_si.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>Ni več povezave z transkodirnim Myth daemon-om. To ni vredu.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Povezava z transkodirnim Myth daemon-om ni možna. Za poizkus zagona lahko pritisnete katerokoli tipko. Če še vedno vidite to sporočilo, potem je nekaj res zelo narobe.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Poizkus povezave z mtd said gostiteljem ni uspel. To je nepopravljivo slabo.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Napaka režne komunikacije. To je nepopravljivo slabo.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Nekaj je narobe, vendar ne vem kaj.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Opravilo %1 od %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Ni opravil in ni kaj drugega za delat. Lahko pritisnete 0 za začetek ripanja DVD-ja.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Ni opravil. Preverjam in/ali čakam na DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Ni opravil in ni kaj drugega za delat. Lahko pritisnete 0 za začetek zajemanja DVD-ja če želite.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Preklic ...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 nov Rip</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Prekliči opravilo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

Nimate definiranega ukaza VCD predvajalnika.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>Vredu, bom pognal Setup</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

Nimate definirane DVC naprave.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

Nimate definiranega ukaza DVD predvajalnika.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

Nimate definirane DVD naprave.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Mesto VCD naprave</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Naprava mora obstajati ter uporabnik mora imeti nastavljene bralne pravice.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Mesto DVD naprave</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation>Ob vstavitvi DVD-ja</translation>
    </message>
    <message>
        <source>Display mythdvd menu menu</source>
        <translation type="obsolete">Prikaži mythdvd menu</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Ne naredi ničesar</translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation>Predvajaj DVD</translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation>Ripaj DVD</translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation>Media nadzor funkcija naj bi bila vključena za uporabo te možnosti (Nastavitve -&gt; Splošno -&gt; CD/DVD Nadzor)</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Splošne nastavitve</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Ukaz DVD predvajalnika</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>To je lahko katerikoli ukaz za zagon DVD predvajalnika (npr. Mplayer, ogle, itd.). Če je prisoten, %d bo prikrojen DVD napravi (npr. /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Ukaz VCD predvajalnika</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>To je lahko katerikoli ukaz za zagon VCD predvajalnika (npr. Mplayer, xine, itd.). Če je prisoten, %d bo prikrojen VCD napravi (npr. /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Nastavitve DVD predvajalnika</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Nastavitve VCD predvajalnika</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Mapa za začasne datoteke</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Ta mapa mora obstajati in uporabnik mora imeti pisalne pravice.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Ukaz za predvajanje naslova</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>To je ukaz uporabljen za predogled določenega naslova na DVD-ju. Če je prisoten, %t bo dodeljen naslovu, %d napravi, %a zvočnemu zapisu, %c zvočnemu kanalu.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Argumenti podnapisov:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Če boste izbrali za ripanje katerekoli podnapise, bo dodan ta ukaz na konec Ukaza za predvajanje naslova, da si boste lahko predogledali podnapise. Če je prisoten %s bo dodeljen k zapisu podnapisov.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Osnovni transkodirni ukaz</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>To je osnovni (brez argumentov) ukaz za zagon transkodiranja.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>MTD število porta</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Število porta, ki se uporablja za komunikacijo z MTD-jem (Myth Transkodirni Daemon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>MTD dnevnik na terminalno okno</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Če nastavljeno, bo MTD prikazoval dnevnik v terminalskem oknu iz katerega je bil zagnan. Drugače bo pisal v datoteko imenovano  mtd.log.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Transkodiranje AC3 zvoka</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Če nastavljeno, bo MTD, kot privzeto, ohranil AC3 (Dolby Digital) zvok v transkodiranih datotekah.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Raje uporabi xvid kot divx</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Če nastavljeno, bo mythdvd, kjer je možno, raje uporabil (brezplačni) xvid kodek, kot divx.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Nice nivo za MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Določuje prioriteto MTD. Višja števila pomenijo nižjo prioriteto (ostalim opravilom na voljo več CPU-ja).</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Hkratna transkodirna opravila</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Določuje število hkratnih transkodirnih opravil. Če je nastavljeno na 1 (privzeto), bo v določenem trenutku aktivno samo eno opravilo.</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Zripani video segmenti</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Če je nastavljeno na karkoli drugega kot 0, bodo video naslovi razdeljeni na datoteke te velikosti (MB). Vpliva tako na perfektno kvaliteto snemanja kot na posredovane datoteke uporabljene za transkodiranje.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>Nastavitve DVD Ripanja</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD nastavitve</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nepozano</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Čakam na dostop do DVD-ja</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Ripanje v datoteko ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Perfekten DVD rip %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Transkodiranje %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Čakam na dovoljenje za začetek transkodiranja</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Prehod transkodiranja 1 od 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Prehod transkodiranja 2 od 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Transkodiranje ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Transkodiranje premišljuje</translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Ripanje/Transkodiranje</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Opravilo 1 od 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Dolžina:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Izberi:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kvaliteta:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Zvočni zapis:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3 zvok:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Podnapisi:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Pogled:</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation>0:00:00</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Naslov 1 od 1</translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Nepoznano</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Naslov %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfektno</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nobeden</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Naslov %1 od %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0  Procesiraj izbrani naslov </translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0  Procesiraj izbrane naslove</translation>
    </message>
</context>
</TS>

==> mythplugins_0.20.2.orig.tar.gz: mythplugins-0.20.2/mythdvd/i18n/mythdvd_si.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>Ni več povezave z transkodirnim Myth daemon-om. To ni vredu.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Povezava z transkodirnim Myth daemon-om ni možna. Za poizkus zagona lahko pritisnete katerokoli tipko. Če še vedno vidite to sporočilo, potem je nekaj res zelo narobe.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Poizkus povezave z mtd said gostiteljem ni uspel. To je nepopravljivo slabo.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Napaka režne komunikacije. To je nepopravljivo slabo.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Nekaj je narobe, vendar ne vem kaj.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Opravilo %1 od %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Ni opravil in ni kaj drugega za delat. Lahko pritisnete 0 za začetek ripanja DVD-ja.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Ni opravil. Preverjam in/ali čakam na DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Ni opravil in ni kaj drugega za delat. Lahko pritisnete 0 za začetek zajemanja DVD-ja če želite.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Preklic ...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 nov Rip</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Prekliči opravilo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

Nimate definiranega ukaza VCD predvajalnika.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>Vredu, bom pognal Setup</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

Nimate definirane DVC naprave.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation type="obsolete">

Nimate definiranega ukaza DVD predvajalnika.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

Nimate definirane DVD naprave.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Mesto VCD naprave</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Naprava mora obstajati ter uporabnik mora imeti nastavljene bralne pravice.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Mesto DVD naprave</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation>Ob vstavitvi DVD-ja</translation>
    </message>
    <message>
        <source>Display mythdvd menu menu</source>
        <translation type="obsolete">Prikaži mythdvd menu</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Ne naredi ničesar</translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation>Predvajaj DVD</translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation>Ripaj DVD</translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation>Media nadzor funkcija naj bi bila vključena za uporabo te možnosti (Nastavitve -&gt; Splošno -&gt; CD/DVD Nadzor)</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Splošne nastavitve</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Ukaz DVD predvajalnika</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>To je lahko katerikoli ukaz za zagon DVD predvajalnika (npr. Mplayer, ogle, itd.). Če je prisoten, %d bo prikrojen DVD napravi (npr. /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Ukaz VCD predvajalnika</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>To je lahko katerikoli ukaz za zagon VCD predvajalnika (npr. Mplayer, xine, itd.). Če je prisoten, %d bo prikrojen VCD napravi (npr. /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Nastavitve DVD predvajalnika</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Nastavitve VCD predvajalnika</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Mapa za začasne datoteke</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Ta mapa mora obstajati in uporabnik mora imeti pisalne pravice.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Ukaz za predvajanje naslova</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>To je ukaz uporabljen za predogled določenega naslova na DVD-ju. Če je prisoten, %t bo dodeljen naslovu, %d napravi, %a zvočnemu zapisu, %c zvočnemu kanalu.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Argumenti podnapisov:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Če boste izbrali za ripanje katerekoli podnapise, bo dodan ta ukaz na konec Ukaza za predvajanje naslova, da si boste lahko predogledali podnapise. Če je prisoten %s bo dodeljen k zapisu podnapisov.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Osnovni transkodirni ukaz</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>To je osnovni (brez argumentov) ukaz za zagon transkodiranja.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>MTD število porta</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Število porta, ki se uporablja za komunikacijo z MTD-jem (Myth Transkodirni Daemon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>MTD dnevnik na terminalno okno</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Če nastavljeno, bo MTD prikazoval dnevnik v terminalskem oknu iz katerega je bil zagnan. Drugače bo pisal v datoteko imenovano  mtd.log.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Transkodiranje AC3 zvoka</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Če nastavljeno, bo MTD, kot privzeto, ohranil AC3 (Dolby Digital) zvok v transkodiranih datotekah.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Raje uporabi xvid kot divx</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Če nastavljeno, bo mythdvd, kjer je možno, raje uporabil (brezplačni) xvid kodek, kot divx.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Nice nivo za MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Določuje prioriteto MTD. Višja števila pomenijo nižjo prioriteto (ostalim opravilom na voljo več CPU-ja).</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Hkratna transkodirna opravila</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Določuje število hkratnih transkodirnih opravil. Če je nastavljeno na 1 (privzeto), bo v določenem trenutku aktivno samo eno opravilo.</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Zripani video segmenti</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Če je nastavljeno na karkoli drugega kot 0, bodo video naslovi razdeljeni na datoteke te velikosti (MB). Vpliva tako na perfektno kvaliteto snemanja kot na posredovane datoteke uporabljene za transkodiranje.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>Nastavitve DVD Ripanja</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD nastavitve</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nepozano</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Čakam na dostop do DVD-ja</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Ripanje v datoteko ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Perfekten DVD rip %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Transkodiranje %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Čakam na dovoljenje za začetek transkodiranja</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Prehod transkodiranja 1 od 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Prehod transkodiranja 2 od 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Transkodiranje ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Transkodiranje premišljuje</translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation>Prikaži MythDvd menu</translation>
    </message>
    <message>
        <source>ISO copy of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting for access to DVD</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Ripanje/Transkodiranje</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Opravilo 1 od 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Dolžina:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Izberi:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kvaliteta:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Zvočni zapis:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3 zvok:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Podnapisi:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Pogled:</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation>0:00:00</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Naslov 1 od 1</translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation type="obsolete">Nepoznano</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Naslov %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfektno</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nobeden</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Naslov %1 od %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0  Procesiraj izbrani naslov </translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0  Procesiraj izbrane naslove</translation>
    </message>
    <message>
        <source>ISO Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Nepozano</translation>
    </message>
</context>
</TS>
